@@ -30,7 +30,7 @@ def createPandasDataFrameOfParameters(hyperparameters, videoName, videoExtension
     'resFolder'                         : os.path.join(cur_dir_path, videoName),
     'nameOfFile'                        : videoName,
     'smoothingFactorDynaParam'          : 0,
-    'nbFramesTakenIntoAccount'          : 28,
+    'nbFramesTakenIntoAccount'          : -2, ## nbFramesTakenIntoAccount will be 100 minimum
     'numberOfBendsIncludedForMaxDetect' : -1,
     'minNbBendForBoutDetect'            : -1,
     'keepSpeedDistDurWhenLowNbBends'    : 1,
@@ -44,5 +44,6 @@ def createPandasDataFrameOfParameters(hyperparameters, videoName, videoExtension
     'saveAllBoutsSuperStructuresInMatlabFormat' : 0
   }
   
-  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, excelFileDataFrame, 1, ['BoutFrameNumberStart', 'tailAngleSymmetry', 'secondBendAmpDividedByFirst', 'tailAngleIntegral'])
+  # forcePandasDfRecreation (third parameter) is set to True here
+  [conditions, genotypes, nbFramesTakenIntoAccount, globParam] = createDataFrame(dataframeOptions, excelFileDataFrame, 1, [])
   
\ No newline at end of file
